@@ -18,6 +18,18 @@ def arg(n:int):
     """
     return sys.argv[n] if len(sys.argv) >= n+1 else ''
 
+def nargs(n:int):
+    """Retrieve remaining command line args starting at index
+
+    Args:
+        n (int): beginning arg index
+
+    Returns:
+        list: arg values or []
+    """
+    return sys.argv[n:]
+
+
 def shift(n:int=1):
     """Shift command line args by n, preserving sys.argv[0]
 
